@@ -1,5 +1,10 @@
 # -*- coding: utf-8 -*-
-__version__ = "3.0.10"
+# PyThaiNLP: Thai Natural Language Processing in Python
+#
+# Copyright (C) 2016-2022 PyThaiNLP Project
+# URL: <https://pythainlp.github.io/>
+# For license information, see LICENSE
+__version__ = "3.1.0"
 
 thai_consonants = "กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรลวศษสหฬอฮ"  # 44 chars
 
@@ -43,7 +48,6 @@ from pythainlp.tokenize import (
     Tokenizer,
     sent_tokenize,
     subword_tokenize,
-    syllable_tokenize,
     word_tokenize,
 )
 from pythainlp.transliterate import romanize, transliterate
