@@ -13,7 +13,9 @@ import requests
 from pythainlp.corpus import corpus_db_path, corpus_db_url, corpus_path
 from pythainlp.tools import get_full_data_path
 from requests.exceptions import HTTPError
-from tinydb import Query, TinyDB
+import tarfile
+import zipfile
+import shutil
 from pythainlp import __version__
 
 
@@ -45,19 +47,17 @@ def get_corpus_db_detail(name: str, version: str = None) -> dict:
     :return: details about a corpus
     :rtype: dict
     """
-    if _CHECK_MODE == "1":
-        local_db = TinyDB(corpus_db_path(), access_mode='r')
-    else:
-        local_db = TinyDB(corpus_db_path())
-    query = Query()
-    if version is None:
-        res = local_db.search(query.name == name)
-    else:
-        res = local_db.search((query.name == name) & (query.version == version))
-    local_db.close()
+    with open(corpus_db_path(), "r", encoding="utf-8-sig") as f:
+        local_db = json.load(f)
 
-    if res:
-        return res[0]
+    if version is None:
+        for corpus in local_db["_default"].values():
+            if corpus["name"] == name:
+                return corpus
+    else:
+        for corpus in local_db["_default"].values():
+            if corpus["name"] == name and corpus["version"] == version:
+                return corpus
 
     return dict()
 
@@ -148,11 +148,13 @@ def get_corpus_default_db(name: str, version: str = None) -> Union[str, None]:
             )
 
 
-def get_corpus_path(name: str,  version: str = None) -> Union[str, None]:
+def get_corpus_path(name: str,  version: str = None, force: bool = False) -> Union[str, None]:
     """
     Get corpus path.
 
     :param str name: corpus name
+    :param str version: version
+    :param bool force: force download
     :return: path to the corpus or **None** of the corpus doesn't \
              exist in the device
     :rtype: str
@@ -199,18 +201,21 @@ def get_corpus_path(name: str,  version: str = None) -> Union[str, None]:
         return default_path
 
     # check if the corpus is in local catalog, download if not
-    corpus_db_detail = get_corpus_db_detail(name)
+    corpus_db_detail = get_corpus_db_detail(name, version=version)
 
     if not corpus_db_detail or not corpus_db_detail.get("filename"):
-        download(name,  version =  version)
-        corpus_db_detail = get_corpus_db_detail(name)
+        download(name,  version=version, force=force)
+        corpus_db_detail = get_corpus_db_detail(name, version=version)
 
     if corpus_db_detail and corpus_db_detail.get("filename"):
         # corpus is in the local catalog, get full path to the file
-        path = get_full_data_path(corpus_db_detail.get("filename"))
+        if corpus_db_detail.get("is_folder"):
+            path = get_full_data_path(corpus_db_detail.get("foldername"))
+        else:
+            path = get_full_data_path(corpus_db_detail.get("filename"))
         # check if the corpus file actually exists, download if not
         if not os.path.exists(path):
-            download(name)
+            download(name,  version=version, force=force)
         if os.path.exists(path):
             return path
 
@@ -231,7 +236,7 @@ def _download(url: str, dst: str) -> int:
     with open(get_full_data_path(dst), "wb") as f:
         pbar = None
         try:
-            from tqdm import tqdm
+            from tqdm.auto import tqdm
 
             pbar = tqdm(total=int(r.headers["Content-Length"]))
         except ImportError:
@@ -374,32 +379,35 @@ def download(
     corpus_db = corpus_db.json()
 
     # check if corpus is available
-    if name in list(corpus_db.keys()):
-        local_db = TinyDB(corpus_db_path())
-        query = Query()
+    if name in corpus_db:
+        with open(corpus_db_path(), "r", encoding="utf-8-sig") as f:
+            local_db = json.load(f)
 
         corpus = corpus_db[name]
         print("Corpus:", name)
         if version is None:
-            for v in corpus["versions"]:
-                if _check_version(corpus["versions"][v]["pythainlp_version"]):
+            for v, file in corpus["versions"].items():
+                if _check_version(file["pythainlp_version"]):
                     version = v
-        else:
-            if version not in list(corpus["versions"].keys()):
-                print("Not found corpus")
-                local_db.close()
-                return False
-            elif _check_version(
-                corpus["versions"][version]["pythainlp_version"]
-            ) is False:
-                print("Versions Corpus not support")
-                local_db.close()
-                return False
+
+        # version may still be None here
+        if version not in corpus["versions"]:
+            print("Not found corpus")
+            return False
+        elif _check_version(
+            corpus["versions"][version]["pythainlp_version"]
+        ) is False:
+            print("Versions Corpus not support")
+            return False
         corpus_versions = corpus["versions"][version]
         file_name = corpus_versions["filename"]
-        found = local_db.search(
-            (query.name == name) & (query.version == version)
-        )
+        found = ""
+        for i, item in local_db["_default"].items():
+            # Do not check version here
+            if item["name"] == name:
+                # Record corpus no. if found in local database
+                found = i
+                break
 
         # If not found in local, download
         if force or not found:
@@ -411,26 +419,64 @@ def download(
                 file_name, corpus_versions["md5"],
             )
 
+            is_folder = False
+            foldername = None
+
+            if corpus_versions["is_tar_gz"] == "True":
+                is_folder = True
+                foldername = name+"_"+str(version)
+                if not os.path.exists(get_full_data_path(foldername)):
+                    os.mkdir(get_full_data_path(foldername))
+                with tarfile.open(get_full_data_path(file_name)) as tar:
+                    tar.extractall(path=get_full_data_path(foldername))
+            elif corpus_versions["is_zip"] == "True":
+                is_folder = True
+                foldername = name+"_"+str(version)
+                if not os.path.exists(get_full_data_path(foldername)):
+                    os.mkdir(get_full_data_path(foldername))
+                with zipfile.ZipFile(
+                    get_full_data_path(file_name), "r"
+                ) as zip:
+                    zip.extractall(path=get_full_data_path(foldername))
+
             if found:
-                local_db.update({"version": version}, query.name == name)
+                local_db["_default"][found]["version"] = version
+                local_db["_default"][found]["filename"] = file_name
+                local_db["_default"][found]["is_folder"] = is_folder
+                local_db["_default"][found]["foldername"] = foldername
             else:
-                local_db.insert(
-                    {"name": name, "version": version, "filename": file_name}
-                )
+                # This awkward behavior is for backward-compatibility with
+                # database files generated previously using TinyDB
+                if local_db["_default"]:
+                    corpus_no = max((
+                        int(no) for no in local_db["_default"]
+                    )) + 1
+                else:
+                    corpus_no = 1
+                local_db["_default"][str(corpus_no)] = {
+                    "name": name,
+                    "version": version,
+                    "filename": file_name,
+                    "is_folder": is_folder,
+                    "foldername": foldername
+                }
+
+            with open(corpus_db_path(), "w", encoding="utf-8") as f:
+                json.dump(local_db, f, ensure_ascii=False)
+        # Check if versions match if the corpus is found in local database
+        # but a re-download is not forced
         else:
-            if local_db.search(
-                query.name == name and query.version == version
-            ):
+            current_ver = local_db["_default"][found]["version"]
+
+            if current_ver == version:
                 # Already has the same version
                 print("- Already up to date.")
             else:
                 # Has the corpus but different version
-                current_ver = local_db.search(query.name == name)[0]["version"]
                 print(f"- Existing version: {current_ver}")
                 print(f"- New version available: {version}")
                 print("- Use download(data_name, force=True) to update")
 
-        local_db.close()
         return True
 
     print("Corpus not found:", name)
@@ -465,16 +511,28 @@ def remove(name: str) -> bool:
     if _CHECK_MODE == "1":
         print("PyThaiNLP is read-only mode. It can't remove corpus.")
         return False
-    db = TinyDB(corpus_db_path())
-    query = Query()
-    data = db.search(query.name == name)
+    with open(corpus_db_path(), "r", encoding="utf-8-sig") as f:
+        db = json.load(f)
+    data = [
+        corpus for corpus in db["_default"].values() if corpus["name"] == name
+    ]
 
     if data:
         path = get_corpus_path(name)
-        os.remove(path)
-        db.remove(query.name == name)
-        db.close()
+        if data[0].get("is_folder"):
+            os.remove(get_full_data_path(data[0].get("filename")))
+            shutil.rmtree(path, ignore_errors=True)
+        else:
+            os.remove(path)
+        for i, corpus in db["_default"].copy().items():
+            if corpus["name"] == name:
+                del db["_default"][i]
+        with open(corpus_db_path(), "w", encoding="utf-8") as f:
+            json.dump(db, f, ensure_ascii=False)
         return True
 
-    db.close()
     return False
+
+
+def get_path_folder_corpus(name, version, *path):
+    return os.path.join(get_corpus_path(name, version), *path)
