@@ -2,7 +2,7 @@
 """
 Thai Textbook Corpus (TTC) word frequency
 
-Credit: Korakot Chaovavanich‎
+Credit: Korakot Chaovavanich
 https://www.facebook.com/photo.php?fbid=363640477387469&set=gm.434330506948445&type=3&permPage=1
 """
 
