@@ -7,10 +7,11 @@ __all__ = [
     "THAI2FIT_TOKENIZER",
     "Tokenizer",
     "Trie",
+    "clause_tokenize",
     "sent_tokenize",
     "subword_tokenize",
-    "syllable_tokenize",
     "word_tokenize",
+    "word_detokenize"
 ]
 
 from pythainlp.corpus import thai_syllables, thai_words
@@ -27,10 +28,11 @@ DEFAULT_DICT_TRIE = DEFAULT_WORD_DICT_TRIE
 
 from pythainlp.tokenize.core import (
     Tokenizer,
+    clause_tokenize,
     sent_tokenize,
     subword_tokenize,
-    syllable_tokenize,
     word_tokenize,
+    word_detokenize,
 )
 
 from pythainlp.corpus import get_corpus as _get_corpus
