@@ -17,12 +17,12 @@ from pythainlp.tokenize import (
     sent_tokenize,
     ssg,
     subword_tokenize,
-    syllable_tokenize,
     tcc,
     word_tokenize,
     sefr_cut,
     tltk,
     oskut,
+    word_detokenize,
 )
 from pythainlp.tokenize import clause_tokenize as sent_clause_tokenize
 from pythainlp.util import dict_trie
@@ -203,6 +203,8 @@ class TestTokenizePackage(unittest.TestCase):
 
         _tokenizer = Tokenizer()
         self.assertEqual(_tokenizer.word_tokenize("ก"), ["ก"])
+        with self.assertRaises(NotImplementedError):
+            Tokenizer(engine="catcut")
 
     def test_clause_tokenize(self):
         self.assertIsNotNone(sent_clause_tokenize(["ฉัน", "ทดสอบ"]))
@@ -269,6 +271,15 @@ class TestTokenizePackage(unittest.TestCase):
         self.assertIsNotNone(
             sent_tokenize(sent_3, engine="tltk",),
         )
+        self.assertIsNotNone(
+            sent_tokenize(sent_1, engine="thaisum",),
+        )
+        self.assertIsNotNone(
+            sent_tokenize(sent_2, engine="thaisum",),
+        )
+        self.assertIsNotNone(
+            sent_tokenize(sent_3, engine="thaisum",),
+        )
         self.assertFalse(
             " "
             in sent_tokenize(
@@ -315,7 +326,6 @@ class TestTokenizePackage(unittest.TestCase):
         )
         self.assertFalse("า" in subword_tokenize("สวัสดีชาวโลก", engine="dict"))
         self.assertEqual(subword_tokenize(None, engine="ssg"), [])
-        self.assertEqual(syllable_tokenize("", engine="ssg"), [])
         self.assertEqual(
             subword_tokenize("แมวกินปลา", engine="ssg"), ["แมว", "กิน", "ปลา"]
         )
@@ -342,30 +352,6 @@ class TestTokenizePackage(unittest.TestCase):
         with self.assertRaises(ValueError):
             subword_tokenize("นกแก้ว", engine="XX")  # engine does not exist
 
-    def test_syllable_tokenize(self):
-        self.assertEqual(syllable_tokenize(None), [])
-        self.assertEqual(syllable_tokenize(""), [])
-        self.assertEqual(
-            syllable_tokenize("สวัสดีชาวโลก"), ["สวัส", "ดี", "ชาว", "โลก"]
-        )
-        self.assertFalse("า" in syllable_tokenize("สวัสดีชาวโลก"))
-        self.assertEqual(syllable_tokenize(None, engine="ssg"), [])
-        self.assertEqual(syllable_tokenize("", engine="ssg"), [])
-        self.assertEqual(
-            syllable_tokenize("แมวกินปลา", engine="ssg"), ["แมว", "กิน", "ปลา"]
-        )
-        self.assertTrue(
-            "ดาว" in syllable_tokenize("สวัสดีดาวอังคาร", engine="ssg")
-        )
-        self.assertFalse(
-            "า" in syllable_tokenize("สวัสดีดาวอังคาร", engine="ssg")
-        )
-        self.assertFalse(
-            " " in syllable_tokenize("พันธมิตร ชา นม", keep_whitespace=False)
-        )
-        with self.assertRaises(ValueError):
-            syllable_tokenize("กรอเทป", engine="XX")  # engine does not exist
-
     def test_word_tokenize(self):
         self.assertEqual(word_tokenize(""), [])
         self.assertEqual(
@@ -624,7 +610,7 @@ class TestTokenizePackage(unittest.TestCase):
         self.assertEqual(ssg.segment(None), [])
         self.assertEqual(ssg.segment(""), [])
         self.assertTrue(
-            "ดาว" in syllable_tokenize("สวัสดีดาวอังคาร", engine="ssg")
+            "ดาว" in subword_tokenize("สวัสดีดาวอังคาร", engine="ssg")
         )
 
     def test_tcc(self):
@@ -655,3 +641,32 @@ class TestTokenizePackage(unittest.TestCase):
         self.assertIsNotNone(
             oskut.segment("ฉันรักภาษาไทยเพราะฉันเป็นคนไทย", engine="scads"),
         )
+
+    def test_word_detokenize(self):
+        self.assertEqual(
+            word_detokenize(["ผม", "เลี้ยง", "5", "ตัว"]),
+            "ผมเลี้ยง 5 ตัว"
+        )
+        self.assertEqual(word_detokenize(
+            ["ผม", "เลี้ยง", " ", "5", "ตัว"], "list"),
+            [["ผม", "เลี้ยง", " ", "5", " ", "ตัว"]]
+        )
+        self.assertEqual(
+            word_detokenize(
+                ["ผม", "เลี้ยง", "5", "10", "ตัว", "ๆ", "คน", "ดี"]
+            ),
+            "ผมเลี้ยง 5 10 ตัว ๆ คนดี"
+        )
+        self.assertEqual(
+            word_detokenize(
+                ["ผม", "เลี้ยง", "5", "ตัว", " ", "ๆ", "คน", "ดี"]
+            ),
+            "ผมเลี้ยง 5 ตัว ๆ คนดี"
+        )
+        self.assertTrue(
+            isinstance(word_detokenize(["ผม", "เลี้ยง", "5", "ตัว"]), str)
+        )
+        self.assertEqual(
+            word_detokenize(["ม่ายย", " ", "ผม", "เลี้ยง", "5", "ตัว"]),
+            "ม่ายย ผมเลี้ยง 5 ตัว"
+        )
