@@ -15,7 +15,6 @@ from pythainlp.util import (
     bahttext,
     collate,
     countthai,
-    delete_tone,
     dict_trie,
     display_thai_char,
     digit_to_text,
@@ -40,7 +39,6 @@ from pythainlp.util import (
     thaiword_to_date,
     thai_digit_to_arabic_digit,
     thai_strftime,
-    thai_time,
     thaiword_to_time,
     time_to_thaiword,
     thai_to_eng,
@@ -48,6 +46,11 @@ from pythainlp.util import (
     thai_keyboard_dist,
     text_to_num,
     words_to_num,
+    sound_syllable,
+    syllable_length,
+    syllable_open_close_detector,
+    tone_detector,
+    thai_word_tone_detector,
 )
 
 
@@ -206,7 +209,7 @@ class TestUtilPackage(unittest.TestCase):
             thai_keyboard_dist("๘", "๙"), thai_keyboard_dist("๙", "๐")
         )
         with self.assertRaises(ValueError):
-            thai_keyboard_dist("ພ","พ")
+            thai_keyboard_dist("ພ", "พ")
 
     # ### pythainlp.util.date
 
@@ -368,10 +371,6 @@ class TestUtilPackage(unittest.TestCase):
                 "24:00"
             )  # input is not in H:M:S format (over 23:59:59)
 
-        self.assertEqual(thai_time("11:12"), time_to_thaiword("11:12"))
-        with self.assertWarns(DeprecationWarning):
-            thai_time("11:16")
-
     def test_thaiword_to_time(self):
         self.assertEqual(thaiword_to_time("บ่ายโมงครึ่ง"), "13:30")
         self.assertEqual(thaiword_to_time("บ่ายสามโมงสิบสองนาที"), "15:12")
@@ -496,6 +495,10 @@ class TestUtilPackage(unittest.TestCase):
         # reorder consonant + follow vowel + tone mark
         self.assertEqual(normalize("\u0e01\u0e32\u0e48"), "\u0e01\u0e48\u0e32")
 
+        # normalize lakkhangyao to sara aa
+        self.assertEqual(normalize("นๅคา"), "นาคา")
+        self.assertEqual(normalize("ฤๅษี"), "ฤๅษี")
+
         # remove repeating following vowels
         self.assertEqual(normalize("กาา"), "กา")
         self.assertEqual(normalize("กา า  า  า"), "กา")
@@ -523,9 +526,6 @@ class TestUtilPackage(unittest.TestCase):
         # remove tone marks
         self.assertEqual(remove_tonemark("จิ้น"), "จิน")
         self.assertEqual(remove_tonemark("เก๋า"), "เกา")
-        self.assertEqual(delete_tone("เจ๋งเป้ง"), remove_tonemark("เจ๋งเป้ง"))
-        with self.assertWarns(DeprecationWarning):
-            delete_tone("ค้าบ")
 
         # remove zero width chars
         self.assertEqual(remove_zw("กา\u200b"), "กา")
@@ -657,3 +657,87 @@ class TestUtilPackage(unittest.TestCase):
             emoji_to_thai("🇹🇭 นี่คือธงประเทศไทย"),
             ":ธง_ไทย: นี่คือธงประเทศไทย",
         )
+
+    def test_sound_syllable(self):
+        test = [
+            ("มา", "live"),
+            ("ดู", "live"),
+            ("ปู", "live"),
+            ("เวลา", "live"),
+            ("ปี", "live"),
+            ("จำ", "live"),
+            ("น้ำ", "live"),
+            ("ใช่", "live"),
+            ("เผ่า", "live"),
+            ("เสา", "live"),
+            ("ไป", "live"),
+            ("จริง", "live"),
+            ("กิน", "live"),
+            ("กำ", "live"),
+            ("มา", "live"),
+            ("สาว", "live"),
+            ("ฉุย", "live"),
+            ("ธุ", "dead"),
+            ("ระ", "dead"),
+            ("กะ", "dead"),
+            ("ทิ", "dead"),
+            ("เกะ", "dead"),
+            ("กะ", "dead"),
+            ("บท", "dead"),
+            ("บาท", "dead"),
+            ("ลาภ", "dead"),
+            ("เมฆ", "dead"),
+            ("เลข", "dead"),
+            ("ธูป", "dead"),
+            ("บ", "dead"),
+            ("บ่", "dead"),
+            ("ก็", "dead"),
+            ("เพราะ", "dead"),
+            ("เกาะ", "dead"),
+            ("แคะ", "dead"),
+        ]
+        for i, j in test:
+            self.assertEqual(sound_syllable(i), j)
+
+    def test_tone_detector(self):
+        data = [
+            ("l", "กด"),
+            ("l", "ต่อ"),
+            ("l", "ฉาก"),
+            ("l", "ใส่"),
+            ("l", "อยาก"),
+            ("l", "อยู่"),
+            ("l", "หนวก"),
+            ("l", "ใหม่"),
+            ("m", "ควาย"),
+            ("m", "ไป"),
+            ("h", "คะ"),
+            ("h", "วัด"),
+            ("h", "ไม้"),
+            ("h", "โต๊ะ"),
+            ("r", "เขา"),
+            ("r", "ก๋ง"),
+            ("r", "หญิง"),
+            ("f", "มาก"),
+            ("f", "ใช่"),
+            ("f", "ไหม้"),
+            ("f", "ต้น"),
+            ("f", "ผู้"),
+        ]
+        for i, j in data:
+            self.assertEqual(tone_detector(j), i)
+
+    def test_syllable_length(self):
+        self.assertEqual(syllable_length("มาก"), "long")
+        self.assertEqual(syllable_length("คะ"), "short")
+
+    def test_syllable_open_close_detector(self):
+        self.assertEqual(syllable_open_close_detector("มาก"), "close")
+        self.assertEqual(syllable_open_close_detector("คะ"), "open")
+
+    def test_thai_word_tone_detector(self):
+        self.assertIsNotNone(thai_word_tone_detector("คนดี"))
+        self.assertEqual(
+            thai_word_tone_detector("ราคา"),
+            [('รา', 'm'), ('คา', 'm')]
+        )
